@@ -1,29 +1,23 @@
 #!/usr/bin/env python3
 
 import requests
+from requests.models import Response
 from typing import Any, Dict, Optional, Union
 
-from requests.models import Response
-from CloudflareAPI.exceptions import CFError, APIError
-
-CLOUDFLARE_API_ROOT_URI = "https://api.cloudflare.com/client/v4"
+from ..exceptions import CFError, APIError
 
 
 class Request:
+    API_ROOT = "https://api.cloudflare.com/client/v4"
+
     def __init__(self, token: str, path: str = "") -> None:
         if not token:
             raise CFError("Invalid api token")
         path = self.__fix_path(path)
-        self.base_url = f"{CLOUDFLARE_API_ROOT_URI}{path}"
+        self.base_url = f"{self.API_ROOT}{path}"
         self.session = requests.Session()
         self.session.headers.update({"Authorization": f"Bearer {token}"})
 
-    @classmethod
-    def verify_token(cls) -> None:
-        verification_url = f"{CLOUDFLARE_API_ROOT_URI}/user/tokens/verify"
-        if cls.get(verification_url)["status"] != "active":
-            raise CFError("Invalid api token")
-
     def __del__(self) -> None:
         if "session" in self.__dict__ and self.session:
             self.session.close()
